@@ -1,4 +1,4 @@
-/*	$NetBSD: hunt.c,v 1.11 2000/04/14 05:58:03 simonb Exp $	*/
+/*	$NetBSD: hunt.c,v 1.12 2001/02/05 00:40:45 christos Exp $	*/
 /*
  *  Hunt
  *  Copyright (c) 1985 Conrad C. Huang, Gregory S. Couch, Kenneth C.R.C. Arnold
@@ -7,7 +7,7 @@
 
 #include <sys/cdefs.h>
 #ifndef lint
-__RCSID("$NetBSD: hunt.c,v 1.11 2000/04/14 05:58:03 simonb Exp $");
+__RCSID("$NetBSD: hunt.c,v 1.12 2001/02/05 00:40:45 christos Exp $");
 #endif /* not lint */
 
 # include	<sys/param.h>
@@ -52,6 +52,10 @@ static struct termios saved_tty;
 extern int	_putchar();
 #endif
 
+#ifndef MAXHOSTNAMELEN
+#define MAXHOSTNAMELEN 256
+#endif
+
 FLAG	Last_player = FALSE;
 # ifdef MONITOR
 FLAG	Am_monitor = FALSE;
@@ -94,6 +98,7 @@ int	main __P((int, char *[]));
 SOCKET *list_drivers __P((void));
 # endif
 
+extern int	Otto_mode;
 /*
  * main:
  *	Main program for local process
@@ -105,7 +110,6 @@ main(ac, av)
 {
 	char		*term;
 	int		c;
-	extern int	Otto_mode;
 	long		enter_status;
 
 	/* Revoke setgid privileges */
